abacusai.api_class.batch_prediction — AbacusAI documentation

# `abacusai.api_class.batch_prediction`

## Module Contents

### Classes

`BatchPredictionArgs` | Helper class that provides a standard way to create an ABC using
`PredictiveModelingBatchPredictionArgs` | Batch Prediction Config for the PREDICTIVE_MODELING problem type
`_BatchPredictionArgsFactory` | Helper class that provides a standard way to create an ABC using

class abacusai.api_class.batch_prediction.BatchPredictionArgs

  Bases: `abacusai.api_class.abstract.ApiClass`

  Helper class that provides a standard way to create an ABC using inheritance.

  _support_kwargs: bool
  kwargs: dict
  problem_type: abacusai.api_class.enums.ProblemType

class abacusai.api_class.batch_prediction.PredictiveModelingBatchPredictionArgs

  Bases: `BatchPredictionArgs`

  Batch Prediction Config for the PREDICTIVE_MODELING problem type :param for_eval: If True, the test fold which was created during training and used for metrics calculation will be used as input data. These predictions are hence, used for model evaluation. :type for_eval: bool :param explainer_type: The type of explainer to use to generate explanations on the batch prediction. :type explainer_type: enums.ExplainerType :param number_of_samples_to_use_for_explainer: Number Of Samples To Use For Kernel Explainer. :type number_of_samples_to_use_for_explainer: int :param include_multi_class_explanations: If True, Includes explanations for all classes in multi-class classification. :type include_multi_class_explanations: bool :param features_considered_constant_for_explanations: Comma separate list of fields to treat as constant in SHAP explanations. :type features_considered_constant_for_explanations: str :param importance_of_records_in_nested_columns: Returns importance of each index in the specified nested column instead of SHAP column explanations. :type importance_of_records_in_nested_columns: str :param explanation_filter_lower_bound: If set explanations will be limited to predictions above this value, Range: [0, 1]. :type explanation_filter_lower_bound: float :param explanation_filter_upper_bound: If set explanations will be limited to predictions below this value, Range: [0, 1]. :type explanation_filter_upper_bound: float :param bound_label: For classification problems specifies the label to which the explanation bounds are applied. :type bound_label: str :param output_columns: A list of column names to include in the prediction result. :type output_columns: list

  for_eval: bool
  explainer_type: abacusai.api_class.enums.ExplainerType
  number_of_samples_to_use_for_explainer: int
  include_multi_class_explanations: bool
  features_considered_constant_for_explanations: str
  importance_of_records_in_nested_columns: str
  explanation_filter_lower_bound: float
  explanation_filter_upper_bound: float
  explanation_filter_label: str
  output_columns: list
  __post_init__()

class abacusai.api_class.batch_prediction._BatchPredictionArgsFactory

  Bases: `abacusai.api_class.abstract._ApiClassFactory`

  Helper class that provides a standard way to create an ABC using inheritance.

  config_abstract_class
  config_class_key = 'problemType'
  config_class_map